@@ -30,12 +30,15 @@ def patch_default_headers():
     RequestHandler.set_default_headers = set_jupyterhub_header
 
 
-def make_app(destport, prefix, command, presentation_path, authtype, request_timeout, ready_check_path, repo, repobranch, repofolder, conda_env_name, debug):
+def make_app(destport, prefix, command, presentation_path, authtype, request_timeout, ready_check_path, repo, 
+                repobranch, repofolder, conda_env_name, debug, logs):
 
     presentation_basename = ''
     presentation_dirname = ''
 
     if presentation_path:
+        if not os.path.isabs(presentation_path):
+            presentation_path = os.path.join(os.getcwd(), presentation_path)
         presentation_basename = os.path.basename(presentation_path)
         presentation_dirname = os.path.dirname(presentation_path)
 
@@ -70,12 +73,13 @@ def make_app(destport, prefix, command, presentation_path, authtype, request_tim
             dict(state={}, authtype=authtype)
         ),
         (
-            r"^"+re.escape(quote(prefix))+r"/(.*)",
+            r"^"+re.escape(prefix.replace('@', '%40'))+r"/(.*)",
             RedirectHandler,
             dict(url=prefix+"/{0}")
         ),
     ],
     debug=debug,
+    logs=logs,
     cookie_secret=os.urandom(32),
     user=os.environ.get('JUPYTERHUB_USER') or '',
     group=os.environ.get('JUPYTERHUB_GROUP') or '',
@@ -126,6 +130,7 @@ def get_ssl_options():
 @click.option('--ip', default=None, help='Address to listen on')
 @click.option('--presentation-path', default='', help='presentation_path substitution variable')
 @click.option('--debug/--no-debug', default=False, help='To display debug level logs')
+@click.option('--logs/--no-logs', default=True, help='To display logs generated by the subprocess')
 @click.option('--authtype', type=click.Choice(['oauth', 'none'], case_sensitive=True), default='oauth')
 @click.option('--request-timeout', default=300, type=click.INT, help='timeout of proxy http calls to subprocess in seconds (default 300)')
 @click.option('--last-activity-interval', default=300, type=click.INT, help='frequency to notify hub that dashboard is still running in seconds (default 300), 0 for never')
@@ -136,13 +141,16 @@ def get_ssl_options():
 @click.option('--repofolder', default='.', help="Relative folder to hold git repo contents (if --repo provided)")
 @click.option('--conda-env', default='', help="Name of conda env to activate before running process")
 @click.option('--allow-root/--no-allow-root', default=True, help='Currently ignored - present to avoid error if this flag is usually passed to singleuser notebook')
+@click.option('--NotebookApp.allow_origin/--no-NotebookApp.allow_origin', 'notebookapp_allow_origin', default=True, help='Currently ignored - present to avoid error if this flag is usually passed to singleuser notebook')
 @click.argument('command', nargs=-1, required=True)
-def run(port, destport, ip, presentation_path, debug, authtype, request_timeout, last_activity_interval, force_alive, ready_check_path, 
-        repo, repobranch, repofolder, conda_env, allow_root, command):
+def run(port, destport, ip, presentation_path, debug, logs, authtype, request_timeout, last_activity_interval, force_alive, ready_check_path, 
+        repo, repobranch, repofolder, conda_env, allow_root, notebookapp_allow_origin, command):
 
     if debug:
         print('Setting debug')
         app_log.setLevel(logging.DEBUG)
+    elif logs:
+        app_log.setLevel(logging.INFO)
 
     prefix = os.environ.get('JUPYTERHUB_SERVICE_PREFIX', '/')
 
@@ -151,7 +159,7 @@ def run(port, destport, ip, presentation_path, debug, authtype, request_timeout,
 
     configure_http_client()
 
-    app = make_app(destport, prefix, list(command), presentation_path, authtype, request_timeout, ready_check_path, repo, repobranch, repofolder, conda_env, debug)
+    app = make_app(destport, prefix, list(command), presentation_path, authtype, request_timeout, ready_check_path, repo, repobranch, repofolder, conda_env, debug, logs)
 
     ssl_options = get_ssl_options()
 
